#ifndef QT_FEATURES_Pdf_src_pdf_qtpdf_config_p_h_H
#define QT_FEATURES_Pdf_src_pdf_qtpdf_config_p_h_H

#define QT_FEATURE_pdf_v8 1

#define QT_FEATURE_pdf_xfa 1

#define QT_FEATURE_pdf_xfa_bmp 1

#define QT_FEATURE_pdf_xfa_gif 1

#define QT_FEATURE_pdf_xfa_png 1

#define QT_FEATURE_pdf_xfa_tiff 1

#define QT_FEATURE_pdf_bitcode -1

#define QT_FEATURE_pdf_static_runtime -1


#endif // QT_FEATURES_Pdf_src_pdf_qtpdf_config_p_h_H
